camelot.camelot.view.plugins.CamelotEditorPlugin

Package camelot :: Package camelot :: Package view :: Package plugins :: Class CamelotEditorPlugin |
[hide private]
[frames] | no frames]

# Class CamelotEditorPlugin

source code

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
initialize(self, core) | source code
isInitialized(self) | source code
createWidget(self, parent) | source code
name(self) | source code
group(self) | source code
toolTip(self) | source code
whatsThis(self) | source code
isContainer(self) | source code
domXml(self) | source code
includeFile(self) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)